exampleKrakow <- function(p, R, theta, M, c, d){
# 1 Define mixture and datamatrix. One row for each contributor, V and U
np <- length(p)
alleles <- 1:np #names of alleles
allg <- allGenotypes(np) #All possible genotypes
ng <- dim(allg)[2]/2
V <- rep(c(1,2),ng) #First contrib fixed to 1/2
U <- c(t(allg))
datamatrix <- rbind(V,U)
rownames(datamatrix) <- c("V","U")

# 2 Define pedigrees
persons <- c("mother","father","V","U")
ped.p <- FamiliasPedigree(id=persons, momid=c(NA,NA,"mother","mother"),
            dadid=c(NA,NA,"father","father"),
            sex= c("female","male","male", "male"))
ped.d <- FamiliasPedigree(id=persons, momid=c(NA,NA,NA,NA),
            dadid=c(NA,NA,NA,NA),
            sex= c("female","male","male", "male"))
mypedigrees <- list(isBrother = ped.p, unrelated=ped.d)

# 3. Define locus. Default mutation model
locus <- FamiliasLocus(p,  alleles,"locus",
            femaleMutationRate = R, maleMutationRate = R)

# Calculate genotype probs
res <- mix3Familias(mypedigrees, locus, datamatrix, kinship=theta)


# 4 Find conditional likelihoods

cLik <- conditionalLikelihoods(M, c, p, d, datamatrix)$likelihood 

#5 Sum
lik.p <- sum(cLik*res$terms[,1])
lik.d <- sum(cLik*res$terms[,2])
LR <- lik.p/lik.d
list(lik.p=lik.p,lik.d=lik.d,LR=lik.p/lik.d)
}
