kappaMat <- function(rho=0, relationship="UN", n1=NULL,  n2=NULL, male = TRUE){
if(rho<0 | rho>0.5) stop("Illegal rho, should be in [0,0.5]")
if (!is.null(n1)) 
	{if(n1<1)
		stop("n1 should be integer >=1 if relevant")
	}
if (!is.null(n2)) 
	{if(n2<1)
		stop("n2 should be integer >=1 if relevant")
	}

kappaES <- function(rho, n1, n2){
	if (n1==1 & n2==1) 
		b <- kappaSibs(rho)
	if ((n1==1 & n2==2)|(n1==2 & n2==1))  
		b <- kappaUncle(rho)
	if (n1>=2&n2>=2){
		k0 <- 1-(1/2)^(n1+n2-2); k1 <- 1-k0
		k11 <-  (((1-rho)^4 + rho^2*(1-rho)^2 + rho^2/2)/4)*((1-rho)/2)^(n1+n2-4)
		k10 <- k01 <- k1 - k11
		k00 <- k0 -k01
		b <- rbind(c(k00,k01),c(k10,k11))
	}
	b
}

kappaPC <- function(rho, n){
	k0 <- 1-(1/2)^(n-1); k1 <- 1-k0
	k11 <- ((1-rho)/2)^(n-1)
	k10 <- k01 <- k1 - k11
	k00 <- k0 -k01
	rbind(c(k00,k01),c(k10,k11))
}

kappaEHS <- function(rho, n1, n2){
	k0 <- 1-(1/2)^(n1+n2-1); k1 <- 1-k0
	k11 <- (1/2)*((1-rho)^2+rho^2)*((1-rho)/2)^(n1+n2-2)
	k10 <- k01 <- k1 - k11
	k00 <- k0 -k01
	rbind(c(k00,k01),c(k10,k11))
}

kappaEHSX <- function(rho, n1, male=TRUE){ #n1 =female meioses
	if(male)  k11 <-1 else {k11 <- (1/2)*((1-rho)^2+rho^2)}
	I <- !male
	k1 <- 0.5^(n1-1*I)
	k0 <- 1-k1
	k11 <- k11*((1-rho)/2)^(n1-2*I)
	k10 <- k01 <- k1 - k11
	k00 <- k0 -k01
	rbind(c(k00,k01),c(k10,k11))
}

kappaUN <- function()
	matrix(c(1,0,0,0,0,0,0,0,0), 3, 3, byrow=T)

kappaPO <- function()
	matrix(c(0,0,0,0,1,0,0,0,0), 3, 3, byrow=T)

kappaMZ <- function()
	matrix(c(0,0,0,0,0,0,0,0,1), 3, 3, byrow=T)

kappaGrand <- function(rho){
	kM <- matrix(0, nrow=3, ncol=3)
	kM[1,1] <- (1-rho)/2
	kM[2,1] <- kM[1,2] <- rho/2
	kM[2,2] <- kM[1,1]
	kM
 }

kappaHalf <- function(rho){
	kM <- matrix(0, nrow=3, ncol = 3)
	kM[1,1] <- 0.5+rho*(rho-1)
	kM[2,1] <- kM[1, 2] <- rho*(1-rho)
	kM[2,2] <- kM[1, 1]
	kM
}

kappaUncle <- function(rho){
	kM <- matrix(0, nrow=3, ncol=3)
	kM[1,1] <- 0.5-0.25*rho*(4*rho^2-8*rho+5)
	kM[2,1] <- kM[1, 2] <- 0.25*rho*(4*rho^2-8*rho+5)
	kM[2,2] <- kM[1, 1]
	kM
}
 
kappaSibs <- function(rho){
	kM <- matrix(0, nrow=3, ncol = 3)
	R <- rho^2 + (1-rho)^2
	kM[1, 1] <- 0.25*R^2
	kM[2,1] <- kM[1,2] <- 0.5*R*(1-R)
	kM[3,1] <- kM[1,3] <- 0.25*(1-R)^2
	kM[2,2] <- 0.5*(1-2*R*(1-R))
	kM[3,2] <- kM[2,3] <- 0.5*R*(1-R)
	kM[3,3] <- 0.25*R^2
	kM
}
km <- "Relationship not implemented"
if (relationship=="UN") 
	km <- kappaUN()
if (relationship=="PO") 
	km <-kappaPO()
if (relationship=="MZ") 
	km <-kappaMZ()
if (relationship=="Grand") 
	km <-kappaGrand(rho)
if (relationship=="Half") 
	km <-kappaHalf(rho)
if (relationship=="Uncle") 
	km <-kappaUncle(rho)
if (relationship=="Sibs") 
	km <-kappaSibs(rho)
if (relationship=="EHS") 
	km <- kappaEHS(rho, n1, n2)
if (relationship=="EHSX") 
	km <- kappaEHSX(rho, n1, male=male)
if (relationship=="ES") 
	km <- kappaES(rho, n1, n2)
if (relationship=="PC") 
	km <- kappaPC(rho, n1)
km
}



