\examples{
  ###Example 1 (Example 7.4 in book)
  freq1 <- c(0.1, 0.3, 0.6)
  freq2 <- c(0.1, 0.2, 0.3, 0.4)
  P <- outer(freq1,freq2) # same as P <- freq1%o%freq2
  data1 <- rbind(c(1,2,3,5),
                 c(0,5,9,11),
                 c(6,12,20,26))
  res1 <- lambdaEst(P,data1)
  #Some LD introduced
  data2 <- data1
  data2[2:3,3:4] <- data2[2:3,3:4]+ c(10,-10,-10,10)
  res2 <- lambdaEst(P,data2)

  ###Example 2. Solution exercise, part 1.
  # First some functions are defined to sample from the dirichlet prior
  # and simulate the datbase.
  rdirichlet <- function (alpha) {
    v <- rgamma(length(alpha), alpha)
    v/sum(v)
  }
  rprior <- function(P,lambda) {
    array(rdirichlet(lambda*P),dim(P))
  }

  rdatabase <- function(N, P, lambda) {
    array(rmultinom(1, N, rprior(P, lambda)), dim(P))
  }
  # The next functions solves part 1,2 and 3 of the mentioned exercise.

  lambdaSim <- function(P,lambda, N=1000, nsim=100, first=log(0.001),
                        last=log(10000),ngrid=1000, pl1=FALSE, pl2=TRUE){
    lambda.vec <- exp(seq(first,last, length.out=ngrid))
    res <- NULL
    loglik <- 0
    dat <- vector("list",nsim)
    for (i in 1: nsim){
      dat[[i]] <- rdatabase(N, P, lambda)
      foo <- lambdaEst(P,dat[[i]],pl=FALSE,first=first,last=last,ngrid=ngrid)
      res <- c(res, foo$lambda.est)
      loglik <- loglik + foo$loglik
    }
    est <- lambda.vec[which.max(loglik)]
    if(pl1) plot(density(res,from=0),
                 main=paste("lambda: ", lambda, "est: ", round(est,3)))
    if(pl2) plot(lambda.vec, loglik,type="l",
                 xlab="lambda", ylab="log likelihood")
    list(allLambda=res,est=est, simData=dat)
  }
  library(genetics)
# A SNP marker
  freq1 <- c(0.2, 0.8) #Aa
  freq2 <- c(0.7, 0.3) #Bb
  freq1 <- c(0.5, 0.5) #Aa
  freq2 <- c(0.5, 0.5) #Bb
  P <- outer(freq1,freq2)
  set.seed(17)
  lambda.est <- r2.est <- D.est <- NULL
  N <- 1000
  ns <- 100
  for (i in 1:ns){
    res <- lambdaSim(P, lambda=1, first=log(0.01), last =log(1000), nsim=1, pl2 = TRUE, N=N)
    n <- res$simData[[1]]
    pA <- (n[1,1]+n[1,2])/N
    pa <- (n[2,1]+n[2,2])/N
    pB <- (n[1,1]+n[2,1])/N
    pb <- (n[1,2]+n[2,2])/N
    p=c(pA=pA, pa=pa, pB=pB, pb=pb)
    D <- n[2,2]/N-pa*pb
    D.est <- c(D.est,D)
    myR2 <- D^2/prod(p)
    r2.est <- c(r2.est, myR2)
    lambda.est <- c(lambda.est,res$est)
  }

  plot(r2.est,log(lambda.est))
  data.frame(r2.est,log(lambda.est))
  mean(lambda.est)
  boxplot(lambda.est)
  median(lambda.est)

  sort(log(lambda.est))

  # Simulation with known lambda and estimation. Figure 2
  par(mfcol=c(3,1))
  # The figure for part 1 of the exercise:
  freq1 <- c(0.1, 0.3, 0.6)
  freq2 <- c(0.1, 0.2, 0.3, 0.4)
  P <- outer(freq1,freq2)
  set.seed(17)
  res <- lambdaSim(P, lambda=30, last =log(1000), nsim=1, pl2 = TRUE, N=1000)
  abline(v=30)
  # The estimate, part 2
  res$est
  # Simulation with known lambda and estimation. Figure 2
  par(mfcol=c(3,1))
  data.frame(lambda0.1 = lambdaSim(P, lambda=0.1,pl1=TRUE, pl2=FALSE, last=log(1000))$est,
             lambda1   = lambdaSim(P, lambda=1,pl1=TRUE, pl2=FALSE,last=log(1000))$est,
             lambda100 = lambdaSim(P, lambda=100,pl1=TRUE, pl2=FALSE,last=log(1000))$est)
  par(mfcol=c(1,1))

  # Example 3. Estimation of lambda. Three markers
  freq1 <- c(0.4,0.6)
  freq2 <- c(0.2,0.8)
  freq3 <- c(0.3,0.7)
  P <- outer(outer(freq1,freq2),freq3) #P <- freq1 %o% freq2 %o% freq3
  set.seed(17)
  par(mfcol=c(3,1))
  data.frame(lambda0.1 = lambdaSim(P, lambda=0.1)$est,
             lambda1   = lambdaSim(P, lambda=1)$est,
             lambda100 = lambdaSim(P, lambda=100)$est)
  par(mfcol=c(1,1))

  #Frequencies  from Exercise 4.17
  freq1 <- c(0.019,0.104,0.877)
  freq2 <- c(0.057,0.066,0.877)
  freq3 <- c(0.354, 0.316,0.33)
  P <- outer(outer(freq1,freq2),freq3) #P <- freq1 %o% freq2 %o% freq3
  set.seed(17)
  par(mfcol=c(3,1))
  data.frame(lambda0.1 = lambdaSim(P, lambda=0.1)$est,
             lambda1   = lambdaSim(P, lambda=1)$est,
             lambda100 = lambdaSim(P, lambda=100)$est)
  par(mfcol=c(1,1))

  #Data from Exercise 4.17, Cluster1
  dat <- array(0,dim(P))
  dat[2,1,1] <- 1; dat[2,2,1] <- 1
  dat[2,1,2] <-1; dat[2,2,2] <- 2
  dat[2,3,3] <- 207
  res <- lambdaEst(P,dat)$lambda.est

  ###Example 4. Part 4 of exercise
  plotLD <- function (f1, f2, first =log(0.01), last=log(10000))
  {
    n1 <- length(f1)
    n2 <- length(f2)
    N1 <- 100
    N2 <- 1000
    P <- outer(f1,f2)
    lambda <- exp(seq(first, last, length.out=N1))
    LD <- array(0, c(N1, n1, n2))
    for (i in 1:N1)
      for (j in 1:N2)
        LD[i,,] <- LD[i,,] + abs(rprior(P, lambda[i])-P)
    LD <- LD/N2
    if(is.na(max(LD))) upper <- 1 else upper <- max(LD)
    plot(lambda, seq(0, upper, length.out=N1), type = "n", log="x",
         ylab = "average absolute LD")
    matlines(lambda, matrix(LD, N1, n1*n2))
  }
  set.seed(17)
  freq1 <- c(0.4,0.6)
  freq2 <- c(0.2,0.8)
  plotLD(freq1,freq2)
  legend("topright",c("haplotype 1-1","haplotype 2-1","haplotype 1-2","haplotype 2-2"),lty=1:4,col=1:4)

  #Example 5
  \dontrun{
    # We first simulate 5 data (function above must be defined)
    # sets each with 1000 haplotypes with known lambda
    freq1 <- c(0.1, 0.3, 0.6)
    freq2 <- c(0.1, 0.2, 0.3, 0.4)
    P <- outer(freq1,freq2)
    set.seed(17)
    res <- lambdaSim(P, lambda=30, last =log(1000), nsim=5, pl2 = TRUE)$simData

    #The below function writes haplo1.txt, ..., haplo5.txt which can
    #be read into FamLinkX to see how close estimated lambda is to original value.
    # The sav file must be consistent with the above specification.

    convertHaplo <- function(dat){
      ndim <- dim(dat[[1]])
      nHaplo <- prod(ndim)
      col1 <- 1:nHaplo
      lr <- length(res)
      files <- vector("list",lr)
      for (i in 1:length(dat)){
        col2 <- c(dat[[i]])
        col3 <- rep(1:ndim[1],ndim[2])
        col4 <- rep(1:ndim[2],each=ndim[1])
        files[[i]] <- data.frame(HaplotypeID=col1, Number=col2,L1=col3,L2=col4)
        write.table(files[[i]],file=paste("haplo",i,".txt",sep=""),quote=FALSE, row.names=FALSE, sep="\t")
      }
      0
    }
    convertHaplo(res)
  }
}

foo = library("BookEKM", logical.return=TRUE)
if(!foo)
{
  function(P, data,pl = TRUE, first = log(0.01), last = log(10000), ngrid = 1000)
  {
    lMultivariateBeta <- function(alpha) sum(lgamma(alpha)) - lgamma(sum(alpha))
    loglilk <- function(data, lambda, P) lMultivariateBeta(lambda * P + data) - lMultivariateBeta(lambda * P)
    if(!is.numeric(P) || any(P <= 0))
      stop("frequencies must be a vector of positive numbers.")
    if(round(sum(P),6) != 1)
      stop("Frequencies must be a vector of positive numbers.")
    if(!is.numeric(P) || any(P <= 0))
      stop("The frequencies must sum to 1.")
    if(any(data < 0))
      stop("Second argument data must be non-negative integers.")
    lambda <- exp(seq(first, last, length.out = ngrid))
    loglikelihood <- lambda
    for(i in 1:ngrid) loglikelihood[i] <- loglik(data, lambda[i], P)
    lambda.est <- lambda[which.max(loglikelihood)]
    if(!is.double(lambda.est))
      stop("Lambda estimate not found, likelihood calculations failed.")
    if(p1)
      plot(lambda, exp(loglikelihood), log = "x", type = "l", ylab = "likelihood")
    list(lambda.est = lambda.est, loglik = loglikelihood)
  }
}
#Begin by defining frequencies and haplotypes observations
freq1= c(0.0015337423,0.012269939,0.061349693,0.073619632,0.11196319,0.19018405,0.20092025,0.082822086,0.033742331,0.0015337423,0.010736196,0.0015337423,0.0030674847,0.0030674847,0.0015337423,0.0076687117,0.056748466,0.029141104,0.024539877,0.013803681,0.039877301,0.023006135,0.010736196,0.0030674847,0.0015337423)
freq2= c(0.0015337423,0.004601227,0.0076687117,0.04601227,0.1196319,0.18711656,0.18865031,0.0015337423,0.18251534,0.004601227,0.0030674847,0.061349693,0.0030674847,0.016871166,0.021472393,0.0015337423,0.056748466,0.0015337423,0.035276074,0.0030674847,0.029141104,0.016871166,0.004601227,0.0015337423)
freq3= c(0.10276074,0.33128834,0.37576687,0.16257669,0.027607362)
P1 = freq1 %o% freq2 %o% freq3
dat1 <- array(0, dim(P1))
dat1[6,5,2] <- 13; dat1[18,20,3] <- 1; dat1[4,4,3] <- 1; dat1[5,6,1] <- 13; dat1[6,8,2] <- 7
dat1[3,11,2] <- 3; dat1[18,16,3] <- 1; dat1[20,11,1] <- 2; dat1[16,4,2] <- 1; dat1[21,5,2] <- 1
dat1[6,11,0] <- 1; dat1[5,8,1] <- 14; dat1[7,8,1] <- 2; dat1[6,8,0] <- 3; dat1[5,3,1] <- 2
dat1[16,16,2] <- 13; dat1[20,6,0] <- 1; dat1[5,21,1] <- 2; dat1[19,6,3] <- 3; dat1[5,5,0] <- 9
dat1[19,4,2] <- 1; dat1[4,8,3] <- 2; dat1[1,8,3] <- 2; dat1[4,8,2] <- 9; dat1[6,5,1] <- 6
dat1[16,5,3] <- 1; dat1[3,5,1] <- 4; dat1[5,8,2] <- 10; dat1[6,5,3] <- 5; dat1[7,4,3] <- 1
dat1[23,8,1] <- 1; dat1[3,8,2] <- 4; dat1[7,4,1] <- 6; dat1[7,5,2] <- 9; dat1[7,5,0] <- 1
dat1[4,5,2] <- 4; dat1[6,4,2] <- 6; dat1[18,8,3] <- 2; dat1[6,3,3] <- 2; dat1[4,21,3] <- 2
dat1[5,14,1] <- 3; dat1[15,20,4] <- 1; dat1[21,5,3] <- 2; dat1[0,5,3] <- 1; dat1[3,5,3] <- 1
dat1[7,8,2] <- 4; dat1[2,4,2] <- 3; dat1[2,8,0] <- 2; dat1[6,11,3] <- 3; dat1[6,8,1] <- 3
dat1[5,5,1] <- 15; dat1[4,11,2] <- 4; dat1[4,6,1] <- 7; dat1[6,5,0] <- 4; dat1[6,20,1] <- 3
dat1[16,8,3] <- 2; dat1[6,4,3] <- 8; dat1[5,6,2] <- 5; dat1[10,6,2] <- 2; dat1[20,8,1] <- 3
dat1[20,6,1] <- 3; dat1[13,6,1] <- 2; dat1[5,4,1] <- 3; dat1[16,6,3] <- 1; dat1[5,5,3] <- 1
dat1[22,4,3] <- 1; dat1[18,5,2] <- 2; dat1[19,18,2] <- 1; dat1[5,4,2] <- 9; dat1[22,14,2] <- 1
dat1[7,6,2] <- 5; dat1[16,16,1] <- 1; dat1[20,6,2] <- 1; dat1[6,6,1] <- 7; dat1[4,4,0] <- 3
dat1[6,8,3] <- 8; dat1[3,6,2] <- 5; dat1[6,13,3] <- 1; dat1[7,4,2] <- 4; dat1[6,13,2] <- 2
dat1[16,15,2] <- 1; dat1[7,5,4] <- 1; dat1[21,5,1] <- 2; dat1[3,3,1] <- 3; dat1[6,11,2] <- 3
dat1[2,6,1] <- 2; dat1[6,10,2] <- 1; dat1[5,18,2] <- 3; dat1[8,4,3] <- 2; dat1[5,11,3] <- 1
dat1[7,3,2] <- 2; dat1[7,6,3] <- 3; dat1[3,16,2] <- 2; dat1[2,8,1] <- 1; dat1[21,8,2] <- 1
dat1[17,18,2] <- 2; dat1[15,3,2] <- 1; dat1[8,11,1] <- 1; dat1[1,5,1] <- 1; dat1[5,14,2] <- 2
dat1[6,16,1] <- 1; dat1[6,21,2] <- 1; dat1[21,4,1] <- 1; dat1[6,6,2] <- 6; dat1[10,11,1] <- 1
dat1[8,4,2] <- 1; dat1[4,16,1] <- 2; dat1[3,8,0] <- 7; dat1[6,20,2] <- 1; dat1[5,12,1] <- 1
dat1[6,18,1] <- 1; dat1[2,11,0] <- 4; dat1[17,16,2] <- 3; dat1[8,21,2] <- 1; dat1[5,16,2] <- 2
dat1[18,9,1] <- 2; dat1[20,13,1] <- 1; dat1[16,18,1] <- 1; dat1[2,6,0] <- 5; dat1[2,3,2] <- 1
dat1[20,4,2] <- 1; dat1[4,5,1] <- 6; dat1[22,8,1] <- 1; dat1[5,5,2] <- 6; dat1[16,3,2] <- 1
dat1[5,17,1] <- 1; dat1[5,8,0] <- 3; dat1[21,4,2] <- 1; dat1[17,20,3] <- 3; dat1[4,13,2] <- 1
dat1[7,6,1] <- 6; dat1[4,11,1] <- 3; dat1[14,16,2] <- 1; dat1[10,14,0] <- 1; dat1[8,6,1] <- 4
dat1[9,6,1] <- 1; dat1[18,5,3] <- 2; dat1[17,8,1] <- 2; dat1[3,16,1] <- 1; dat1[4,20,2] <- 2
dat1[16,16,0] <- 1; dat1[5,3,0] <- 1; dat1[6,6,0] <- 3; dat1[6,3,1] <- 4; dat1[4,6,2] <- 2
dat1[8,3,1] <- 1; dat1[16,6,0] <- 1; dat1[16,6,2] <- 1; dat1[15,4,3] <- 2; dat1[16,12,2] <- 1
dat1[4,18,4] <- 1; dat1[2,6,2] <- 4; dat1[6,14,2] <- 3; dat1[7,21,4] <- 1; dat1[21,18,1] <- 1
dat1[6,11,1] <- 3; dat1[19,8,1] <- 1; dat1[4,5,3] <- 1; dat1[15,6,1] <- 1; dat1[3,4,1] <- 2
dat1[4,5,0] <- 1; dat1[2,5,2] <- 3; dat1[6,4,1] <- 3; dat1[1,4,1] <- 1; dat1[2,6,4] <- 1
dat1[5,8,3] <- 1; dat1[2,8,2] <- 5; dat1[8,8,3] <- 1; dat1[8,5,3] <- 1; dat1[8,4,1] <- 2
dat1[21,4,3] <- 1; dat1[20,5,2] <- 2; dat1[4,2,2] <- 1; dat1[4,6,3] <- 1; dat1[5,3,3] <- 1
dat1[4,3,1] <- 1; dat1[4,6,0] <- 3; dat1[8,18,2] <- 1; dat1[3,20,3] <- 1; dat1[18,20,2] <- 1
dat1[11,11,1] <- 1; dat1[17,18,4] <- 1; dat1[5,4,4] <- 1; dat1[3,8,1] <- 3; dat1[19,5,1] <- 1
dat1[16,11,1] <- 1; dat1[16,8,0] <- 1; dat1[5,6,0] <- 2; dat1[20,2,2] <- 1; dat1[7,3,1] <- 1
dat1[3,9,1] <- 1; dat1[4,8,1] <- 5; dat1[5,11,0] <- 1; dat1[8,18,1] <- 1; dat1[19,11,3] <- 1
dat1[2,6,3] <- 2; dat1[5,11,2] <- 2; dat1[22,3,1] <- 1; dat1[16,5,2] <- 1; dat1[4,16,2] <- 4
dat1[8,14,2] <- 1; dat1[20,18,2] <- 1; dat1[24,13,1] <- 1; dat1[17,22,4] <- 1; dat1[7,5,1] <- 1
dat1[2,7,2] <- 1; dat1[6,2,4] <- 1; dat1[1,11,1] <- 1; dat1[8,3,2] <- 1; dat1[16,8,1] <- 1
dat1[19,6,2] <- 1; dat1[4,16,3] <- 1; dat1[6,18,2] <- 4; dat1[16,21,3] <- 1; dat1[4,20,1] <- 1
dat1[16,20,1] <- 1; dat1[18,8,2] <- 1; dat1[2,5,1] <- 2; dat1[23,13,2] <- 1; dat1[16,22,4] <- 1
dat1[6,8,4] <- 1; dat1[4,3,2] <- 2; dat1[3,4,2] <- 2; dat1[20,21,2] <- 1; dat1[20,5,3] <- 1
dat1[10,4,3] <- 1; dat1[5,6,3] <- 2; dat1[8,6,3] <- 2; dat1[3,19,2] <- 1; dat1[6,6,3] <- 2
dat1[6,6,4] <- 2; dat1[21,10,1] <- 1; dat1[20,4,1] <- 1; dat1[17,5,1] <- 2; dat1[21,6,3] <- 1
dat1[21,8,3] <- 1; dat1[22,4,1] <- 2; dat1[5,2,0] <- 1; dat1[20,20,1] <- 1; dat1[22,3,3] <- 1
dat1[5,22,4] <- 1; dat1[18,4,4] <- 1; dat1[6,4,4] <- 1; dat1[4,6,4] <- 1; dat1[1,5,3] <- 1
dat1[21,20,1] <- 1; dat1[6,3,2] <- 1; dat1[7,11,3] <- 2; dat1[16,18,2] <- 1; dat1[3,11,3] <- 1
dat1[5,16,1] <- 1; dat1[8,6,2] <- 1; dat1[17,8,2] <- 1; dat1[1,13,2] <- 1; dat1[3,6,0] <- 1
dat1[7,3,3] <- 1; dat1[10,5,1] <- 1; dat1[16,13,2] <- 1; dat1[18,21,2] <- 1; dat1[7,18,2] <- 1
dat1[6,1,2] <- 1; dat1[20,6,3] <- 2; dat1[20,8,3] <- 1; dat1[6,1,3] <- 1; dat1[16,20,2] <- 2
dat1[21,4,0] <- 1; dat1[5,0,1] <- 1; dat1[10,3,1] <- 1; dat1[20,18,3] <- 1; dat1[17,13,2] <- 1
dat1[3,6,1] <- 3; dat1[12,8,1] <- 1; dat1[17,4,3] <- 1; dat1[20,5,1] <- 2; dat1[6,19,1] <- 1
dat1[6,14,0] <- 1; dat1[3,4,0] <- 1; dat1[5,13,2] <- 1; dat1[5,11,1] <- 1; dat1[5,18,1] <- 1
dat1[3,5,2] <- 1; dat1[2,4,1] <- 1; dat1[17,18,3] <- 1; dat1[18,8,1] <- 1; dat1[12,6,2] <- 1
dat1[2,5,0] <- 1; dat1[6,16,2] <- 1; dat1[7,8,3] <- 1; dat1[4,3,3] <- 1; dat1[4,2,1] <- 1
dat1[2,14,0] <- 1; dat1[6,23,2] <- 1; dat1[2,16,2] <- 1; dat1[18,4,1] <- 1; dat1[6,16,3] <- 1
dat1[7,5,3] <- 2; dat1[1,5,2] <- 1; dat1[8,14,0] <- 1; dat1[5,6,4] <- 1; dat1[3,1,0] <- 1
dat1[17,21,2] <- 1
freq4= c(0.0015337423,0.012269939,0.061349693,0.073619632,0.11196319,0.19018405,0.20092025,0.082822086,0.033742331,0.0015337423,0.010736196,0.0015337423,0.0030674847,0.0030674847,0.0015337423,0.0076687117,0.056748466,0.029141104,0.024539877,0.013803681,0.039877301,0.023006135,0.010736196,0.0030674847,0.0015337423)
freq5= c(0.0015337423,0.004601227,0.0076687117,0.04601227,0.1196319,0.18711656,0.18865031,0.0015337423,0.18251534,0.004601227,0.0030674847,0.061349693,0.0030674847,0.016871166,0.021472393,0.0015337423,0.056748466,0.0015337423,0.035276074,0.0030674847,0.029141104,0.016871166,0.004601227,0.0015337423)
P2 = freq4 %o% freq5
dat2 <- array(0, dim(P2))
dat2[6,5] <- 28; dat2[18,20] <- 2; dat2[4,4] <- 4; dat2[5,6] <- 23; dat2[6,8] <- 22
dat2[3,11] <- 4; dat2[18,16] <- 1; dat2[20,11] <- 2; dat2[16,4] <- 1; dat2[21,5] <- 5
dat2[6,11] <- 10; dat2[5,8] <- 28; dat2[7,8] <- 7; dat2[5,3] <- 4; dat2[16,16] <- 15
dat2[20,6] <- 7; dat2[5,21] <- 2; dat2[19,6] <- 4; dat2[5,5] <- 31; dat2[19,4] <- 1
dat2[4,8] <- 16; dat2[1,8] <- 2; dat2[16,5] <- 2; dat2[3,5] <- 6; dat2[7,4] <- 11
dat2[23,8] <- 1; dat2[3,8] <- 14; dat2[7,5] <- 14; dat2[4,5] <- 12; dat2[6,4] <- 18
dat2[18,8] <- 4; dat2[6,3] <- 7; dat2[4,21] <- 2; dat2[5,14] <- 5; dat2[15,20] <- 1
dat2[0,5] <- 1; dat2[2,4] <- 4; dat2[2,8] <- 8; dat2[4,11] <- 7; dat2[4,6] <- 14
dat2[6,20] <- 4; dat2[16,8] <- 4; dat2[10,6] <- 2; dat2[20,8] <- 4; dat2[13,6] <- 2
dat2[5,4] <- 13; dat2[16,6] <- 3; dat2[22,4] <- 3; dat2[18,5] <- 4; dat2[19,18] <- 1
dat2[22,14] <- 1; dat2[7,6] <- 14; dat2[6,6] <- 20; dat2[3,6] <- 9; dat2[6,13] <- 3
dat2[16,15] <- 1; dat2[3,3] <- 3; dat2[2,6] <- 14; dat2[6,10] <- 1; dat2[5,18] <- 4
dat2[8,4] <- 5; dat2[5,11] <- 5; dat2[7,3] <- 4; dat2[3,16] <- 3; dat2[21,8] <- 2
dat2[17,18] <- 4; dat2[15,3] <- 1; dat2[8,11] <- 1; dat2[1,5] <- 3; dat2[6,16] <- 3
dat2[6,21] <- 1; dat2[21,4] <- 4; dat2[10,11] <- 1; dat2[4,16] <- 7; dat2[5,12] <- 1
dat2[6,18] <- 5; dat2[2,11] <- 4; dat2[17,16] <- 3; dat2[8,21] <- 1; dat2[5,16] <- 3
dat2[18,9] <- 2; dat2[20,13] <- 1; dat2[16,18] <- 2; dat2[2,3] <- 1; dat2[20,4] <- 2
dat2[22,8] <- 1; dat2[16,3] <- 1; dat2[5,17] <- 1; dat2[17,20] <- 3; dat2[4,13] <- 1
dat2[14,16] <- 1; dat2[10,14] <- 1; dat2[8,6] <- 7; dat2[9,6] <- 1; dat2[17,8] <- 3
dat2[4,20] <- 3; dat2[8,3] <- 2; dat2[15,4] <- 2; dat2[16,12] <- 1; dat2[4,18] <- 1
dat2[6,14] <- 4; dat2[7,21] <- 1; dat2[21,18] <- 1; dat2[19,8] <- 1; dat2[15,6] <- 1
dat2[3,4] <- 5; dat2[2,5] <- 6; dat2[1,4] <- 1; dat2[8,8] <- 1; dat2[8,5] <- 1
dat2[20,5] <- 5; dat2[4,2] <- 2; dat2[4,3] <- 4; dat2[8,18] <- 2; dat2[3,20] <- 1
dat2[11,11] <- 1; dat2[19,5] <- 1; dat2[16,11] <- 1; dat2[20,2] <- 1; dat2[3,9] <- 1
dat2[19,11] <- 1; dat2[22,3] <- 2; dat2[8,14] <- 2; dat2[20,18] <- 2; dat2[24,13] <- 1
dat2[17,22] <- 1; dat2[2,7] <- 1; dat2[6,2] <- 1; dat2[1,11] <- 1; dat2[16,21] <- 1
dat2[16,20] <- 3; dat2[23,13] <- 1; dat2[16,22] <- 1; dat2[20,21] <- 1; dat2[10,4] <- 1
dat2[3,19] <- 1; dat2[21,10] <- 1; dat2[17,5] <- 2; dat2[21,6] <- 1; dat2[5,2] <- 1
dat2[20,20] <- 1; dat2[5,22] <- 1; dat2[18,4] <- 2; dat2[21,20] <- 1; dat2[7,11] <- 2
dat2[1,13] <- 1; dat2[10,5] <- 1; dat2[16,13] <- 1; dat2[18,21] <- 1; dat2[7,18] <- 1
dat2[6,1] <- 2; dat2[5,0] <- 1; dat2[10,3] <- 1; dat2[17,13] <- 1; dat2[12,8] <- 1
dat2[17,4] <- 1; dat2[6,19] <- 1; dat2[5,13] <- 1; dat2[12,6] <- 1; dat2[2,14] <- 1
dat2[6,23] <- 1; dat2[2,16] <- 1; dat2[3,1] <- 1; dat2[17,21] <- 1
freq6= c(0.0015337423,0.004601227,0.0076687117,0.04601227,0.1196319,0.18711656,0.18865031,0.0015337423,0.18251534,0.004601227,0.0030674847,0.061349693,0.0030674847,0.016871166,0.021472393,0.0015337423,0.056748466,0.0015337423,0.035276074,0.0030674847,0.029141104,0.016871166,0.004601227,0.0015337423)
freq7= c(0.10276074,0.33128834,0.37576687,0.16257669,0.027607362)
P3 = freq6 %o% freq7
dat3 <- array(0, dim(P3))
dat3[5,2] <- 43; dat3[20,3] <- 5; dat3[4,3] <- 18; dat3[6,1] <- 49; dat3[8,2] <- 42
dat3[11,2] <- 12; dat3[16,3] <- 3; dat3[11,1] <- 14; dat3[4,2] <- 29; dat3[11,0] <- 6
dat3[8,1] <- 39; dat3[8,0] <- 16; dat3[3,1] <- 14; dat3[16,2] <- 27; dat3[6,0] <- 16
dat3[21,1] <- 2; dat3[6,3] <- 19; dat3[5,0] <- 16; dat3[8,3] <- 21; dat3[5,1] <- 43
dat3[5,3] <- 19; dat3[4,1] <- 23; dat3[3,3] <- 6; dat3[21,3] <- 3; dat3[14,1] <- 3
dat3[20,4] <- 1; dat3[11,3] <- 8; dat3[20,1] <- 7; dat3[6,2] <- 34; dat3[18,2] <- 14
dat3[14,2] <- 7; dat3[16,1] <- 6; dat3[4,0] <- 5; dat3[13,3] <- 1; dat3[13,2] <- 8
dat3[15,2] <- 1; dat3[5,4] <- 1; dat3[10,2] <- 1; dat3[3,2] <- 9; dat3[21,2] <- 5
dat3[20,2] <- 6; dat3[12,1] <- 1; dat3[18,1] <- 5; dat3[9,1] <- 3; dat3[13,1] <- 2
dat3[17,1] <- 1; dat3[14,0] <- 4; dat3[16,0] <- 1; dat3[3,0] <- 1; dat3[12,2] <- 1
dat3[18,4] <- 2; dat3[21,4] <- 1; dat3[6,4] <- 5; dat3[2,2] <- 2; dat3[4,4] <- 3
dat3[22,4] <- 3; dat3[7,2] <- 1; dat3[2,4] <- 1; dat3[8,4] <- 1; dat3[19,2] <- 1
dat3[10,1] <- 1; dat3[2,0] <- 1; dat3[1,2] <- 1; dat3[1,3] <- 1; dat3[0,1] <- 1
dat3[18,3] <- 2; dat3[19,1] <- 1; dat3[2,1] <- 1; dat3[23,2] <- 1; dat3[1,0] <- 1
freq8= c(0.0015337423,0.012269939,0.061349693,0.073619632,0.11196319,0.19018405,0.20092025,0.082822086,0.033742331,0.0015337423,0.010736196,0.0015337423,0.0030674847,0.0030674847,0.0015337423,0.0076687117,0.056748466,0.029141104,0.024539877,0.013803681,0.039877301,0.023006135,0.010736196,0.0030674847,0.0015337423)
freq9= c(0.10276074,0.33128834,0.37576687,0.16257669,0.027607362)
P4 = freq8 %o% freq9
dat4 <- array(0, dim(P4))
dat4[6,2] <- 51; dat4[18,3] <- 6; dat4[4,3] <- 9; dat4[5,1] <- 58; dat4[3,2] <- 18
dat4[20,1] <- 13; dat4[16,2] <- 23; dat4[21,2] <- 3; dat4[6,0] <- 12; dat4[7,1] <- 16
dat4[20,0] <- 1; dat4[19,3] <- 4; dat4[5,0] <- 17; dat4[19,2] <- 3; dat4[1,3] <- 3
dat4[4,2] <- 29; dat4[6,1] <- 32; dat4[16,3] <- 5; dat4[3,1] <- 17; dat4[5,2] <- 40
dat4[6,3] <- 31; dat4[7,3] <- 10; dat4[23,1] <- 1; dat4[7,2] <- 25; dat4[7,0] <- 1
dat4[15,4] <- 1; dat4[21,3] <- 5; dat4[0,3] <- 1; dat4[3,3] <- 3; dat4[2,2] <- 18
dat4[2,0] <- 13; dat4[4,1] <- 26; dat4[10,2] <- 2; dat4[13,1] <- 2; dat4[5,3] <- 6
dat4[22,3] <- 2; dat4[18,2] <- 5; dat4[22,2] <- 1; dat4[16,1] <- 5; dat4[20,2] <- 7
dat4[4,0] <- 7; dat4[7,4] <- 2; dat4[21,1] <- 6; dat4[2,1] <- 6; dat4[8,3] <- 6
dat4[17,2] <- 8; dat4[15,2] <- 1; dat4[8,1] <- 9; dat4[1,1] <- 3; dat4[10,1] <- 3
dat4[8,2] <- 6; dat4[3,0] <- 10; dat4[18,1] <- 4; dat4[22,1] <- 4; dat4[17,3] <- 5
dat4[14,2] <- 1; dat4[10,0] <- 1; dat4[9,1] <- 1; dat4[17,1] <- 4; dat4[16,0] <- 3
dat4[15,3] <- 2; dat4[4,4] <- 2; dat4[19,1] <- 2; dat4[15,1] <- 1; dat4[2,4] <- 1
dat4[11,1] <- 1; dat4[17,4] <- 2; dat4[5,4] <- 3; dat4[2,3] <- 2; dat4[24,1] <- 1
dat4[6,4] <- 5; dat4[23,2] <- 1; dat4[16,4] <- 1; dat4[20,3] <- 5; dat4[10,3] <- 1
dat4[18,4] <- 1; dat4[1,2] <- 2; dat4[21,0] <- 1; dat4[12,1] <- 1; dat4[12,2] <- 1
dat4[8,0] <- 1
freq10= c(0.0015337423,0.0076687117,0.0015337423,0.13803681,0.02607362,0.0061349693,0.0030674847,0.0030674847,0.015337423,0.030674847,0.061349693,0.012269939,0.14110429,0.20245399,0.1595092,0.11656442,0.038343558,0.023006135,0.0076687117,0.0015337423,0.0015337423,0.0015337423)
freq11= c(0.10276074,0.33128834,0.37576687,0.16257669,0.027607362)
P5 = freq10 %o% freq11
dat5 <- array(0, dim(P5))
dat5[3,2] <- 34; dat5[12,3] <- 11; dat5[17,3] <- 3; dat5[13,1] <- 37; dat5[13,2] <- 54
dat5[14,3] <- 16; dat5[3,1] <- 34; dat5[14,1] <- 44; dat5[8,2] <- 7; dat5[15,2] <- 26
dat5[12,0] <- 11; dat5[15,0] <- 7; dat5[16,0] <- 3; dat5[4,1] <- 4; dat5[15,3] <- 22
dat5[9,2] <- 6; dat5[1,2] <- 1; dat5[11,2] <- 3; dat5[3,3] <- 11; dat5[5,1] <- 1
dat5[13,3] <- 23; dat5[12,1] <- 31; dat5[14,2] <- 31; dat5[7,0] <- 1; dat5[12,2] <- 36
dat5[12,4] <- 3; dat5[10,3] <- 7; dat5[10,2] <- 16; dat5[13,0] <- 13; dat5[15,1] <- 20
dat5[5,2] <- 3; dat5[17,1] <- 4; dat5[10,1] <- 13; dat5[7,1] <- 1; dat5[6,3] <- 1
dat5[4,4] <- 1; dat5[17,2] <- 6; dat5[8,3] <- 1; dat5[21,2] <- 1; dat5[16,1] <- 9
dat5[14,0] <- 13; dat5[11,1] <- 2; dat5[3,0] <- 6; dat5[9,0] <- 2; dat5[17,0] <- 1
dat5[1,1] <- 3; dat5[18,2] <- 2; dat5[18,0] <- 1; dat5[10,0] <- 4; dat5[17,4] <- 1
dat5[3,4] <- 5; dat5[9,1] <- 10; dat5[16,2] <- 9; dat5[11,3] <- 3; dat5[4,0] <- 3
dat5[9,4] <- 1; dat5[18,3] <- 2; dat5[4,2] <- 7; dat5[16,4] <- 1; dat5[13,4] <- 5
dat5[9,3] <- 1; dat5[16,3] <- 3; dat5[4,3] <- 2; dat5[6,1] <- 1; dat5[15,4] <- 1
dat5[0,2] <- 1; dat5[20,2] <- 1; dat5[1,0] <- 1; dat5[8,1] <- 1; dat5[8,0] <- 1
dat5[19,1] <- 1; dat5[2,2] <- 1
lambdaCluster1<- lambdaEst(P1,dat1)$lambda.est
dev.new()
lambdaCluster2<- lambdaEst(P2,dat2)$lambda.est
dev.new()
lambdaCluster3<- lambdaEst(P3,dat3)$lambda.est
dev.new()
lambdaCluster4<- lambdaEst(P4,dat4)$lambda.est
dev.new()
lambdaCluster5<- lambdaEst(P5,dat5)$lambda.est
lambdaCluster1
lambdaCluster2
lambdaCluster3
lambdaCluster4
lambdaCluster5
lambdaAverage = (lambdaCluster1 + lambdaCluster2 + lambdaCluster3 + lambdaCluster4 + lambdaCluster5)/5
lambdaAverage

#Petter 12 mai
freq1 <- c(0.1, 0.3, 0.6)
freq2 <- c(0.1, 0.2, 0.3, 0.4)
F <- freq1%o%freq2
lMultivariateBeta <- function(alpha)
  sum(lgamma(alpha)) - lgamma(sum(alpha))
loglik <- function(data, lambda, base)
  lMultivariateBeta(lambda*base + data) -
  lMultivariateBeta(lambda*base)
lambda <- exp(seq(log(1),log(10000), length.out=1000))
likelihood <- lambda

N <- 1000
result <- matrix(0, N, 2)
for (j in 1:N) {
  data1 <- matrix(rmultinom(1, 100, F), 3, 4)
#  for (i in 1:1000) likelihood[i] <-
#      exp(loglik(data1, lambda[i], F))
  FfromData <- apply(data1, 1, sum) %o% apply(data1, 2, sum)/10000
  for (i in 1:1000) likelihood[i] <-
    exp(loglik(data1, lambda[i], FfromData))
  result[j,1] <- lambda[which.max(likelihood)]
  #  plot(lambda, likelihood, log="x", type="l")
  result[j,2] <- fisher.test(data1)$p.value
}
plot(result, xlab="Estimate of lambda", ylab="Exact test p-value", log="x")
}

f=function(lambda)
  (100+lambda)/(10+lambda*0.06)
