install.packages("http://familias.name/BookEKM_1.0.zip")
library(BookEKM)
rdirichlet <- function (alpha) {
  v <- rgamma(length(alpha), alpha)
  v/sum(v)
}
rprior <- function(P,lambda) {
  array(rdirichlet(lambda*P),dim(P))
}

rdatabase <- function(N, P, lambda) {
  array(rmultinom(1, N, rprior(P, lambda)), dim(P))
}


lambdaSim <- function(P,lambda, N=1000, nsim=100, first=log(0.001),
                      last=log(10000),ngrid=1000, pl1=FALSE, pl2=TRUE){
  lambda.vec <- exp(seq(first,last, length.out=ngrid))
  res <- NULL
  loglik <- 0
  dat <- vector("list",nsim)
  for (i in 1: nsim){
    dat[[i]] <- rdatabase(N, P, lambda)
    foo <- lambdaEst(P,dat[[i]],pl=FALSE,first=first,last=last,ngrid=ngrid)
    res <- c(res, foo$lambda.est)
    loglik <- loglik + foo$loglik
  }
  est <- lambda.vec[which.max(loglik)]
  if(pl1) plot(density(res,from=0),
               main=paste("lambda: ", lambda, "est: ", round(est,3)))
  if(pl2) plot(lambda.vec, loglik,type="l",
               xlab="lambda", ylab="log likelihood")
  list(allLambda=res,est=est, simData=dat)
}

  # freq1 <- c(0.2, 0.8) #Aa
  # freq2 <- c(0.7, 0.3) #Bb
  freq1 <- c(0.5, 0.5) #Aa Not much change with freq1 and freq2 above
  freq2 <- c(0.5, 0.5) #Bb
  P <- outer(freq1,freq2)
  eps <- 1e-6
  set.seed(17)
  lambda.est <- r2.est <- D.est <- NULL
  N <- 1000
  ns <- 100
  lambda=100
  for (i in 1:ns){
    res <- lambdaSim(P, lambda=lambda, first=log(0.01), last =log(1000),
                     nsim=100, pl2 = TRUE, N=N)
    n <- res$simData[[1]]
    pA <- (n[1,1]+n[1,2])/N
    pa <- (n[2,1]+n[2,2])/N
    pB <- (n[1,1]+n[2,1])/N
    pb <- (n[1,2]+n[2,2])/N
    p <- c(pA,pa,pB,pb)
    D <- n[2,2]/N-pa*pb
    D.est <- c(D.est,D)
    myR2 <- D^2/prod(p)
    r2.est <- c(r2.est, myR2)
    lambda.est <- c(lambda.est,res$est)
  }
  r2.est[is.na(r2.est)] <- 1 #For small lambda, some few R2=NA and this are set to 1.
  plot(r2.est,log(lambda.est),
       main= paste("lambda = ",lambda), xlab="R2", ylab="log(lambda)")
  #plot(D.est, log(lambda.est)) #some rs may be NA and then one can look at D"
