\name{balance1}
\alias{balance1}
\title{
Makes Mutation Matrix Balanced
}
\description{
An irreducible and aperiodic mutation matrix
is tranformed to satisfy detailed balanced (DB) using the Metropolis-Hastings algorithm.
DB is important since swapping of genotypes can be performed
without changing LR if and only DB holds.
}
\usage{
balance1(Q, p, alternative=2)
}

\arguments{
  \item{Q}{
 irreducible and aperiodic mutation matrix
}
  \item{p}{
 allele frequency
}
  \item{alternative}{
 Currently 1 or 2. See details.
  }
}

\value{
\item{P }{Transformed mutation matrix}
\item{balancedCheck }{Should be TRUE, i.e., indicate that DB holds.}
\item{stationaryCheck }{Should be TRUE, i.e., indicate that stationarity holds.}
\item{expectedMut}{Expected mutation rate. Should remain unchanged for default.}
}
\details{The default option \code{alternative=2} gives the substitution
q_{ij}   =>    q_{ij} min(1, p_j/p_i * q_{ji}/q_{ij})
while \code{alternative=1} implements the standard Metropolis-Hastings.
q_{ij}    =>   (p_i q_{ij} + p_j q_{ji} ) / (2p_i)
}
\references{
Egeland et al(2016)
}
\author{
Thore Egeland <Thore.Egeland@nmbu.no>
}

\examples{
library(Familias)
n <- 4
p <- 1:n
p <- c(0.1,0.3,0.4,0.2)
R <- (n-1)*0.001
p <- p/sum(p)
n <- length(p)
Q <-FamiliasLocus(frequencies=p, allelenames= 1:length(p), 
                  name="locus1", MutationModel="Equal", 
                  MutationRate=R)$maleMutationMatrix
balance1(Q,p)
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.

